@@ -5,11 +5,15 @@ Root url's map for application
 from django.conf.urls.defaults import *
 
 from djangotribune.views.help import ReadmePage
-from djangotribune.views.remote import RemotePlainView, RemoteJsonView, RemoteXmlView, RemoteCrapXmlView
-from djangotribune.views.post import PostBoardView, PostRemotePlainView, PostRemoteJsonView, PostRemoteXmlView, PostRemoteCrapXmlView
+from djangotribune.views.remote import (RemotePlainView, RemoteJsonView, RemoteXmlView, 
+                                        RemoteCrapXmlView)
+from djangotribune.views.post import (PostBoardView, PostBoardNoScriptView, 
+                                        PostRemotePlainView, PostRemoteJsonView, 
+                                        PostRemoteXmlView, PostRemoteCrapXmlView)
 
 urlpatterns = patterns('',
     url(r'^$', PostBoardView.as_view(), name='tribune-board'),
+    url(r'^noscript/$', PostBoardNoScriptView.as_view(), name='tribune-board-noscript'),
     
     url(r'^readme/$', ReadmePage.as_view(), name='tribune-readme'),
     
